@@ -53,7 +53,6 @@ cnc_error_cb (GdaClient *client, GdaConnection *cnc, GList *error_list, gpointer
 
 		/* FIXME: add to an internal list, to be able to get all the errors occured
 		   for this connection at a later time */
-		gda_error_list_free (error_list);
 	}
 }
 
@@ -145,5 +144,6 @@ components_connection_close (GdaConnection *cnc)
 void
 components_connection_close_all (void)
 {
-	gda_client_close_all_connections (client);
+	if (GDA_IS_CLIENT (client))
+		gda_client_close_all_connections (client);
 }
